@@ -377,7 +377,7 @@ class Topology:
         }
 
         for chain in self.chains:
-            c = out.addChain()
+            c = out.addChain(id=chain.chain_id)
             for residue in chain.residues:
                 r = out.addResidue(residue.name, c, id=str(residue.resSeq))
                 for atom in residue.atoms:
@@ -385,7 +385,12 @@ class Topology:
                         element = None
                     else:
                         element = app.Element.getBySymbol(atom.element.symbol)
-                    a = out.addAtom(atom.name, element, r)
+                    
+                    # If we are using a compatible version of OpenMM, add formal charge
+                    try:
+                        a = out.addAtom(atom.name, element, r, formalCharge=atom.formal_charge)
+                    except TypeError: # This will occur if the version of OpenMM does not support formal charge (version<=8.2)
+                        a = out.addAtom(atom.name, element, r)
                     atom_mapping[atom] = a
 
         for bond in self.bonds:
@@ -423,6 +428,7 @@ class Topology:
             mdtraj topology.
         """
         app = import_("openmm.app")
+
         bond_mapping = {
             app.Single: Single,
             app.Double: Double,
@@ -441,7 +447,7 @@ class Topology:
         atom_mapping = {}
 
         for chain in value.chains():
-            c = out.add_chain()
+            c = out.add_chain(chain_id=chain.id)
             for residue in chain.residues():
                 try:
                     r = out.add_residue(residue.name, c, resSeq=int(residue.id))
@@ -452,7 +458,11 @@ class Topology:
                         element = elem.virtual
                     else:
                         element = elem.get_by_symbol(atom.element.symbol)
-                    a = out.add_atom(atom.name, element, r)
+                    # If we are using a compatible version of OpenMM (>=8.2), add formal charge 
+                    if hasattr(atom, "formalCharge"):
+                        a = out.add_atom(atom.name, element, r, formal_charge=atom.formalCharge)
+                    else:
+                        a = out.add_atom(atom.name, element, r)
                     atom_mapping[atom] = a
 
         for bond in value.bonds():
@@ -821,7 +831,7 @@ class Topology:
         self._atoms.remove(a)
         self._numAtoms -= 1
 
-    def add_atom(self, name, element, residue, serial=None):
+    def add_atom(self, name, element, residue, serial=None, formal_charge=None):
         """Create a new Atom and add it to the Topology.
 
         Parameters
@@ -832,8 +842,10 @@ class Topology:
             The element of the atom to add
         residue : mdtraj.topology.Residue
             The Residue to add it to
-        serial : int
+        serial : int, optional
             Serial number associated with the atom.
+        formal_charge : int, optional
+            The formal charge of the atom to add.
 
         Returns
         -------
@@ -842,7 +854,7 @@ class Topology:
         """
         if element is None:
             element = elem.virtual
-        atom = Atom(name, element, self._numAtoms, residue, serial=serial)
+        atom = Atom(name, element, self._numAtoms, residue, serial=serial, formal_charge=formal_charge)
         self._atoms.append(atom)
         self._numAtoms += 1
         residue._atoms.append(atom)
@@ -1647,9 +1659,11 @@ class Atom:
     serial : int
         The serial number from the PDB specification. Unlike index,
         this may not be contiguous or 0-indexed.
+    formal_charge : float
+
     """
 
-    def __init__(self, name, element, index, residue, serial=None):
+    def __init__(self, name, element, index, residue, serial=None, formal_charge=None):
         """Construct a new Atom.  You should call add_atom() on the Topology instead of calling this directly."""
         # The name of the Atom
         self.name = name
@@ -1661,6 +1675,8 @@ class Atom:
         self.residue = residue
         # The not-necessarily-contiguous "serial" number from the PDB spec
         self.serial = serial
+        # The formal charge of the atom
+        self.formal_charge = formal_charge
 
     @property
     def n_bonds(self):
