@@ -36,6 +36,7 @@ from math import ceil
 import numpy as np
 from packaging.version import Version
 
+import mdtraj
 from mdtraj.formats.registry import FormatRegistry
 from mdtraj.utils import cast_indices, ensure_type, import_, in_units_of
 
@@ -388,7 +389,10 @@ class AmberRestartFile:
             raise ValueError("Can only write 1 frame to a restart file!")
         if time is not None:
             try:
-                time = float(time)
+                if isinstance(time, np.ndarray):
+                    time = float(time.item())
+                else:
+                    time = float(time)
             except TypeError:
                 raise TypeError("Can only provide a single time")
         else:
@@ -795,7 +799,10 @@ class AmberNetCDFRestartFile:
             raise ValueError("Can only write 1 frame to a restart file!")
         if time is not None:
             try:
-                time = float(time)
+                if isinstance(time, np.ndarray):
+                    time = float(time.item())
+                else:
+                    time = float(time)
             except TypeError:
                 raise TypeError("Can only provide a single time")
         else:
@@ -840,7 +847,10 @@ class AmberNetCDFRestartFile:
 
         # Write the time, coordinates, and box info
         if time is not None:
-            self._handle.variables["time"][0] = float(time)
+            if isinstance(time, np.ndarray):
+                self._handle.variables["time"][0] = float(time.item())
+            else:
+                self._handle.variables["time"][0] = float(time)
         self._handle.variables["coordinates"][:, :] = coordinates[0, :, :]
         if cell_lengths is not None:
             self._handle.variables["cell_angles"][:] = cell_angles[0, :]
@@ -851,15 +861,13 @@ class AmberNetCDFRestartFile:
         """Initialize the headers and convention properties of the NetCDF
         restart file
         """
-        from mdtraj import version as mdtraj_version
-
         ncfile = self._handle
         ncfile.Conventions = "AMBERRESTART"
         ncfile.ConventionVersion = "1.0"
         ncfile.title = "NetCDF Restart file written by MDTraj w/out velocities"
         ncfile.application = "Omnia"
         ncfile.program = "MDTraj"
-        ncfile.programVersion = mdtraj_version.short_version
+        ncfile.programVersion = mdtraj.__version__
         # Dimensions
         ncfile.createDimension("spatial", 3)
         ncfile.createDimension("atom", n_atoms)
