@@ -21,31 +21,24 @@
 ##############################################################################
 
 
-##############################################################################
-# Imports
-##############################################################################
-
-from __future__ import print_function, division
-import os
 import itertools
+import os
+
 import numpy as np
-from mdtraj.utils import ensure_type, cast_indices, in_units_of
+
 from mdtraj.formats.registry import FormatRegistry
-from mdtraj.utils.six import string_types, PY3
-from mdtraj.utils.six.moves import xrange
+from mdtraj.utils.unit import in_units_of
+from mdtraj.utils.validation import cast_indices, ensure_type
 
-__all__ = ['MDCRDTrajectoryFile', 'load_mdcrd']
+__all__ = ["MDCRDTrajectoryFile", "load_mdcrd"]
 
 
-##############################################################################
-# Classes
-##############################################################################
-
 class _EOF(IOError):
     pass
 
-@FormatRegistry.register_loader('.mdcrd')
-@FormatRegistry.register_loader('.crd')
+
+@FormatRegistry.register_loader(".mdcrd")
+@FormatRegistry.register_loader(".crd")
 def load_mdcrd(filename, top=None, stride=None, atom_indices=None, frame=None):
     """Load an AMBER mdcrd file.
 
@@ -54,7 +47,7 @@ def load_mdcrd(filename, top=None, stride=None, atom_indices=None, frame=None):
     filename : path-like
         Path of AMBER mdcrd file.
     top : {str, Trajectory, Topology}
-        The BINPOS format does not contain topology information. Pass in either
+        The mdcrd format does not contain topology information. Pass in either
         the path to a pdb file, a trajectory, or a topology to supply this
         information.
     stride : int, default=None
@@ -76,7 +69,7 @@ def load_mdcrd(filename, top=None, stride=None, atom_indices=None, frame=None):
     --------
     mdtraj.MDCRDTrajectoryFile :  Low level interface to MDCRD files
     """
-    from mdtraj.core.trajectory import _parse_topology, Trajectory
+    from mdtraj.core.trajectory import _parse_topology
 
     # we make it not required in the signature, but required here. although this
     # is a little wierd, its good because this function is usually called by a
@@ -85,9 +78,10 @@ def load_mdcrd(filename, top=None, stride=None, atom_indices=None, frame=None):
     if top is None:
         raise ValueError('"top" argument is required for load_mdcrd')
 
-    if not isinstance(filename, (string_types, os.PathLike)):
-        raise TypeError('filename must be of type path-like for load_mdcrd. '
-            'you supplied %s' % type(filename))
+    if not isinstance(filename, (str, os.PathLike)):
+        raise TypeError(
+            "filename must be of type path-like for load_mdcrd. " "you supplied %s" % type(filename),
+        )
 
     topology = _parse_topology(top)
     atom_indices = cast_indices(atom_indices)
@@ -98,13 +92,17 @@ def load_mdcrd(filename, top=None, stride=None, atom_indices=None, frame=None):
             n_frames = 1
         else:
             n_frames = None
-        return f.read_as_traj(topology, n_frames=n_frames, stride=stride,
-                              atom_indices=atom_indices)
+        return f.read_as_traj(
+            topology,
+            n_frames=n_frames,
+            stride=stride,
+            atom_indices=atom_indices,
+        )
 
 
-@FormatRegistry.register_fileobject('.mdcrd')
-@FormatRegistry.register_fileobject('.crd')
-class MDCRDTrajectoryFile(object):
+@FormatRegistry.register_fileobject(".mdcrd")
+@FormatRegistry.register_fileobject(".crd")
+class MDCRDTrajectoryFile:
     """Interface for reading and writing to an AMBER mdcrd files.
     This is a file-like object, that both reading or writing depending
     on the `mode` flag. It implements the context manager protocol,
@@ -134,12 +132,17 @@ class MDCRDTrajectoryFile(object):
         exists on disk, should we overwrite it?
     """
 
-    distance_unit = 'angstroms'
+    distance_unit = "angstroms"
 
-    def __init__(self, filename,  n_atoms=None, mode='r', has_box='detect',
-                 force_overwrite=True):
-        """Open an AMBER mdcrd file for reading/writing.
-        """
+    def __init__(
+        self,
+        filename,
+        n_atoms=None,
+        mode="r",
+        has_box="detect",
+        force_overwrite=True,
+    ):
+        """Open an AMBER mdcrd file for reading/writing."""
         self._is_open = False
         self._filename = filename
         self._n_atoms = n_atoms
@@ -154,24 +157,26 @@ class MDCRDTrajectoryFile(object):
         if has_box not in [True, False, "detect"]:
             raise ValueError('has_box must be one of [True, False, "detect"]')
 
-        if mode == 'r':
+        if mode == "r":
             if n_atoms is None:
-                raise ValueError('To open a mdcrd file in mode="r", you must '
-                                 'supply the number of atoms, "n_atoms"')
+                raise ValueError(
+                    'To open a mdcrd file in mode="r", you must ' 'supply the number of atoms, "n_atoms"',
+                )
             if not os.path.exists(filename):
-                raise IOError("The file '%s' doesn't exist" % filename)
-            self._fh = open(filename, 'rb')
+                raise OSError("The file '%s' doesn't exist" % filename)
+            self._fh = open(filename, "rb")
             self._is_open = True
             self._fh.readline()  # read comment
             self._line_counter += 1
-        elif mode == 'w':
+        elif mode == "w":
             if os.path.exists(filename) and not force_overwrite:
-                raise IOError('"%s" already exists' % filename)
-            self._fh = open(filename, 'wb')
+                raise OSError('"%s" already exists' % filename)
+            self._fh = open(filename, "wb")
             self._is_open = True
         else:
-            raise ValueError('mode must be one of "r" or "w". '
-                             'you supplied "%s"' % mode)
+            raise ValueError(
+                'mode must be one of "r" or "w". ' 'you supplied "%s"' % mode,
+            )
 
     def close(self):
         """Close the mdcrd file"""
@@ -213,16 +218,26 @@ class MDCRDTrajectoryFile(object):
             A trajectory object containing the loaded portion of the file.
         """
         from mdtraj.core.trajectory import Trajectory
+
         if atom_indices is not None:
             topology = topology.subset(atom_indices)
 
         initial = int(self._frame_index)
-        xyz, cell_lengths = self.read(n_frames=n_frames, stride=stride, atom_indices=atom_indices)
+        xyz, cell_lengths = self.read(
+            n_frames=n_frames,
+            stride=stride,
+            atom_indices=atom_indices,
+        )
         if len(xyz) == 0:
             return Trajectory(xyz=np.zeros((0, topology.n_atoms, 3)), topology=topology)
 
         in_units_of(xyz, self.distance_unit, Trajectory._distance_unit, inplace=True)
-        in_units_of(cell_lengths, self.distance_unit, Trajectory._distance_unit, inplace=True)
+        in_units_of(
+            cell_lengths,
+            self.distance_unit,
+            Trajectory._distance_unit,
+            inplace=True,
+        )
 
         if cell_lengths is None:
             cell_angles = None
@@ -232,7 +247,7 @@ class MDCRDTrajectoryFile(object):
 
         if stride is None:
             stride = 1
-        time = (stride*np.arange(len(xyz))) + initial
+        time = (stride * np.arange(len(xyz))) + initial
 
         t = Trajectory(xyz=xyz, topology=topology, time=time)
         t.unitcell_lengths = cell_lengths
@@ -262,14 +277,15 @@ class MDCRDTrajectoryFile(object):
             array of shape=(n_frames, 3). Otherwise, unitcell_angles will be
             None.
         """
-        if not self._mode == 'r':
-            raise ValueError('read() is only available when file is opened '
-                             'in mode="r"')
+        if not self._mode == "r":
+            raise ValueError(
+                "read() is only available when file is opened " 'in mode="r"',
+            )
 
         if n_frames is None:
             frame_counter = itertools.count()
         else:
-            frame_counter = xrange(n_frames)
+            frame_counter = range(n_frames)
 
         if stride is None:
             stride = 1
@@ -301,42 +317,46 @@ class MDCRDTrajectoryFile(object):
         if not all(b is not None for b in boxes):
             # but if some of them had box information and others didn't
             # that probably means there was a bug in the parsing.
-            raise IOError('Inconsistent box information. Try manually '
-                          'setting has_box? Your mdcrd file might be '
-                          'corrupt.')
+            raise OSError(
+                "Inconsistent box information. Try manually " "setting has_box? Your mdcrd file might be " "corrupt.",
+            )
 
         return coords, np.array(boxes, dtype=np.float32)
 
     def _read(self):
         "Read a single frame"
         i = 0
-        coords = np.empty(self._n_atoms*3, dtype=np.float32)
+        coords = np.empty(self._n_atoms * 3, dtype=np.float32)
         box = None
 
         while i < self._n_atoms * 3:
             line = self._fh.readline()
             self._line_counter += 1
 
-            if line == b'':
+            if line == b"":
                 raise _EOF()
             try:
-                items = [float(line[j:j+8])
-                         for j in range(0, len(line.rstrip()), 8)]
+                items = [float(line[j : j + 8]) for j in range(0, len(line.rstrip()), 8)]
                 assert 0 < len(items) <= 10
             except Exception:
-                raise IOError('mdcrd parse error on line %d of "%s". This file '
-                              'does not appear to be a valid mdcrd file.' % \
-                              (self._line_counter,  self._filename))
+                raise OSError(
+                    'mdcrd parse error on line %d of "%s". This file '
+                    "does not appear to be a valid mdcrd file." % (self._line_counter, self._filename),
+                )
 
             length = len(items)
 
             if i + length > len(coords):
-                raise IOError(
-                    'mdcrd parse error: specified n_atoms (%d) is likely incorrect. '
-                    'Incorrect buffer size encountered on line=%d' % (
-                    self._n_atoms, self._line_counter))
+                raise OSError(
+                    "mdcrd parse error: specified n_atoms (%d) is likely incorrect. "
+                    "Incorrect buffer size encountered on line=%d"
+                    % (
+                        self._n_atoms,
+                        self._line_counter,
+                    ),
+                )
 
-            coords[i:i+length] = items
+            coords[i : i + length] = items
             i += length
 
             if i == self._n_atoms * 3:
@@ -351,7 +371,7 @@ class MDCRDTrajectoryFile(object):
                     box = peek
                 else:
                     if self._has_box is True:
-                        raise IOError('Box information not found in file.')
+                        raise OSError("Box information not found in file.")
                     self._fh.seek(-len(line), 1)
                     self._fh.seek(here)
                 break
@@ -372,23 +392,37 @@ class MDCRDTrajectoryFile(object):
             `a`, `b`, `c`. By convention the lengths should be in units
             of angstroms.
         """
-        if not self._mode == 'w':
-            raise ValueError('write() is only available when file is opened '
-                             'in mode="w"')
+        if not self._mode == "w":
+            raise ValueError(
+                "write() is only available when file is opened " 'in mode="w"',
+            )
 
-        xyz = ensure_type(xyz, np.float32, 3, 'xyz', can_be_none=False,
-                shape=(None, None, 3), warn_on_cast=False,
-                add_newaxis_on_deficient_ndim=True)
-        cell_lengths = ensure_type(cell_lengths, np.float32, 2, 'cell_lengths',
-                can_be_none=True, shape=(len(xyz), 3), warn_on_cast=False,
-                add_newaxis_on_deficient_ndim=True)
+        xyz = ensure_type(
+            xyz,
+            np.float32,
+            3,
+            "xyz",
+            can_be_none=False,
+            shape=(None, None, 3),
+            warn_on_cast=False,
+            add_newaxis_on_deficient_ndim=True,
+        )
+        cell_lengths = ensure_type(
+            cell_lengths,
+            np.float32,
+            2,
+            "cell_lengths",
+            can_be_none=True,
+            shape=(len(xyz), 3),
+            warn_on_cast=False,
+            add_newaxis_on_deficient_ndim=True,
+        )
 
         if self._w_has_box is None:
             # this is the first write()
             self._n_atoms = xyz.shape[1]
-            comment = 'TITLE : Created by MDTraj with %d atoms\n' % self._n_atoms
-            if PY3:
-                comment = comment.encode('ascii')
+            comment = "TITLE : Created by MDTraj with %d atoms\n" % self._n_atoms
+            comment = comment.encode("ascii")
             self._fh.write(comment)
 
             if cell_lengths is None:
@@ -397,12 +431,14 @@ class MDCRDTrajectoryFile(object):
                 self._w_has_box = True
         elif self._w_has_box is True:
             if cell_lengths is None:
-                raise ValueError('This mdcrd file must contain unitcell '
-                                 'information')
+                raise ValueError(
+                    "This mdcrd file must contain unitcell " "information",
+                )
         elif self._w_has_box is False:
             if cell_lengths is not None:
-                raise ValueError('This mdcrd file must not contain unitcell '
-                                 'information')
+                raise ValueError(
+                    "This mdcrd file must not contain unitcell " "information",
+                )
         else:
             raise RuntimeError()
 
@@ -411,11 +447,10 @@ class MDCRDTrajectoryFile(object):
                 lfdone = False
                 out = "%8.3f" % coord
                 if len(out) > 8:
-                    raise ValueError('Overflow error')
-                if PY3:
-                    out = out.encode('ascii')
+                    raise ValueError("Overflow error")
+                out = out.encode("ascii")
                 self._fh.write(out)
-                if (j+1) % 10 == 0:
+                if (j + 1) % 10 == 0:
                     self._fh.write(b"\n")
                     lfdone = True
 
@@ -423,9 +458,8 @@ class MDCRDTrajectoryFile(object):
                 self._fh.write(b"\n")
 
             if cell_lengths is not None:
-                line = "%8.3f %8.3f %8.3f\n" % tuple(cell_lengths[i])
-                if PY3:
-                    line = line.encode('ascii')
+                line = "{:8.3f} {:8.3f} {:8.3f}\n".format(*tuple(cell_lengths[i]))
+                line = line.encode("ascii")
                 self._fh.write(line)
 
     def seek(self, offset, whence=0):
@@ -441,7 +475,7 @@ class MDCRDTrajectoryFile(object):
             2: move relative to the end of file, offset should be <= 0.
             Seeking beyond the end of a file is not supported
         """
-        if self._mode == 'r':
+        if self._mode == "r":
             advance, absolute = None, None
             if whence == 0 and offset >= 0:
                 if offset >= self._frame_index:
@@ -453,16 +487,16 @@ class MDCRDTrajectoryFile(object):
             elif whence == 1 and offset < 0:
                 absolute = offset + self._frame_index
             elif whence == 2 and offset <= 0:
-                raise NotImplementedError('offsets from the end are not supported yet')
+                raise NotImplementedError("offsets from the end are not supported yet")
             else:
-                raise IOError('Invalid argument')
+                raise OSError("Invalid argument")
 
             if advance is not None:
                 for i in range(advance):
                     self._read()  # advance and throw away these frames
             elif absolute is not None:
                 self._fh.close()
-                self._fh = open(self._filename, 'rb')
+                self._fh = open(self._filename, "rb")
                 self._fh.readline()  # read comment
                 self._frame_index = 0
                 self._line_counter = 1
@@ -472,7 +506,7 @@ class MDCRDTrajectoryFile(object):
                 raise RuntimeError()
 
         else:
-            raise NotImplementedError('offsets in write mode are not supported yet')
+            raise NotImplementedError("offsets in write mode are not supported yet")
 
     def tell(self):
         """Current file position
