@@ -36,7 +36,7 @@ import numpy as np
 
 import mdtraj
 from mdtraj.formats.registry import FormatRegistry
-from mdtraj.utils import cast_indices, ensure_type, import_, in_units_of
+from mdtraj.utils import cast_indices, ensure_type, in_units_of
 
 __all__ = ["NetCDFTrajectoryFile", "load_netcdf"]
 
