@@ -20,35 +20,63 @@
 # License along with MDTraj. If not, see <http://www.gnu.org/licenses/>.
 ##############################################################################
 
-from __future__ import print_function, division
 
-__all__ = ['baker_hubbard', 'shrake_rupley', 'kabsch_sander', 'compute_distances',
-           'compute_distances_t', 'compute_displacements', 'compute_angles', 
-           'compute_dihedrals', 'compute_phi', 'compute_psi', 'compute_chi1', 'compute_chi2',
-           'compute_chi3', 'compute_chi4','compute_chi5', 'compute_omega',
-           'compute_rg', 'compute_contacts', 'compute_drid',
-           'compute_center_of_mass', 'compute_center_of_geometry',
-           'wernet_nilsson', 'compute_dssp', 'compute_neighbors',
-           'compute_neighborlist', 'compute_rdf', 'compute_rdf_t', 'compute_nematic_order',
-           'compute_inertia_tensor', 'compute_gyration_tensor', 'find_closest_contact',
-           'compute_directors', 'principal_moments', 'asphericity', 'acylindricity', 
-           'relative_shape_antisotropy',
-           'dipole_moments', 'static_dielectric', 'isothermal_compressability_kappa_T',
-           'thermal_expansion_alpha_P',  'density'
-           ]
-
-from .rg import *
 from .angle import *
-from .distance import *
-from .dihedral import *
-from .hbond import *
-from .sasa import *
 from .contact import *
+from .dihedral import *
+from .distance import *
 from .drid import *
 from .dssp import *
-from .neighbors import *
+from .hbond import *
 from .neighborlist import *
-from .thermodynamic_properties import *
-from .rdf import *
+from .neighbors import *
 from .order import *
+from .rdf import *
+from .rg import *
+from .sasa import *
 from .shape import *
+from .thermodynamic_properties import *
+
+__all__ = [
+    "baker_hubbard",
+    "shrake_rupley",
+    "kabsch_sander",
+    "compute_distances",
+    "compute_distances_t",
+    "compute_displacements",
+    "compute_angles",
+    "compute_dihedrals",
+    "compute_phi",
+    "compute_psi",
+    "compute_chi1",
+    "compute_chi2",
+    "compute_chi3",
+    "compute_chi4",
+    "compute_chi5",
+    "compute_omega",
+    "compute_rg",
+    "compute_contacts",
+    "compute_drid",
+    "compute_center_of_mass",
+    "compute_center_of_geometry",
+    "wernet_nilsson",
+    "compute_dssp",
+    "compute_neighbors",
+    "compute_neighborlist",
+    "compute_rdf",
+    "compute_rdf_t",
+    "compute_nematic_order",
+    "compute_inertia_tensor",
+    "compute_gyration_tensor",
+    "find_closest_contact",
+    "compute_directors",
+    "principal_moments",
+    "asphericity",
+    "acylindricity",
+    "relative_shape_antisotropy",
+    "dipole_moments",
+    "static_dielectric",
+    "isothermal_compressability_kappa_T",
+    "thermal_expansion_alpha_P",
+    "density",
+]
