@@ -6,7 +6,7 @@ extern "C" {
 
 void sasa(const int n_frames, const int n_atoms, const float* xyzlist,
           const float* atom_radii, const int n_sphere_points,
-          const int* atom_mapping, const int n_groups, float* out);
+          const int* atom_mapping, const int* atom_selection_mask, const int n_groups, float* out);
 
 
 #ifdef __cplusplus
