@@ -1,5 +1,6 @@
+#!/bin/env python
 """
-Module simtk.unit
+Module openmm.unit
 
 Contains classes Unit and ScaledUnit.
 
@@ -12,7 +13,7 @@ Portions copyright (c) 2012 Stanford University and the Authors.
 Authors: Christopher M. Bruns
 Contributors: Peter Eastman
 
-Permission is hereby granted, free of charge, to any person obtaining a 
+Permission is hereby granted, free of charge, to any person obtaining a
 copy of this software and associated documentation files (the "Software"),
 to deal in the Software without restriction, including without limitation
 the rights to use, copy, modify, merge, publish, distribute, sublicense,
@@ -31,44 +32,40 @@ OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE
 USE OR OTHER DEALINGS IN THE SOFTWARE.
 """
 
-from __future__ import print_function, division
-
 __author__ = "Christopher M. Bruns"
 __version__ = "0.5"
 
+
 import math
 import sys
-from .mymatrix import MyMatrix, zeros
-from .basedimension import BaseDimension
+
 from .baseunit import BaseUnit
+from .mymatrix import MyMatrix, zeros
 from .standard_dimensions import *
 
-__all__ = ['Unit', 'ScaledUnit', 'UnitSystem', 'is_unit', 'dimensionless', 'in_units_of']
 
-
-def _first_key(dct):
-    "Return the first key from a dictionary"
-    if sys.version > '3':
-        return next(iter(dct.keys()))
-    else:
-        return dct.iterkeys().next()
-
-class Unit(object):
+class Unit:
     """
     Physical unit such as meter or ampere.
     """
+
+    __array_priority__ = 100
+
     def __init__(self, base_or_scaled_units):
         """Create a new Unit.
-        
-        Parameters:
-         - self (Unit) The newly created Unit.
-         - base_or_scaled_units (dict) Keys are BaseUnits or ScaledUnits.  Values are exponents (numbers).
+
+        Parameters
+        ----------
+        self : Unit
+            The newly created Unit.
+        base_or_scaled_units : dict
+            Keys are BaseUnits or ScaledUnits.  Values are exponents (numbers).
         """
         # Unit contents are of two types: BaseUnits and ScaledUnits
         self._top_base_units = {}
         self._all_base_units = {}
         self._scaled_units = []
-        for (base_or_scaled_unit, power) in base_or_scaled_units.items():
+        for base_or_scaled_unit, power in base_or_scaled_units.items():
             if power == 0:
                 continue
             if isinstance(base_or_scaled_unit, BaseUnit):
@@ -108,29 +105,27 @@ class Unit(object):
         # TODO - also handle non-simple units, i.e. units with multiple BaseUnits/ScaledUnits
         assert len(self._top_base_units) == 1
         assert len(self._scaled_units) == 0
-        dimension = _first_key(self._top_base_units)
+        dimension = next(iter(self._top_base_units))
         base_unit_dict = self._top_base_units[dimension]
         assert len(base_unit_dict) == 1
-        parent_base_unit = _first_key(base_unit_dict)
+        parent_base_unit = next(iter(base_unit_dict))
         parent_exponent = base_unit_dict[parent_base_unit]
         new_base_unit = BaseUnit(parent_base_unit.dimension, name, symbol)
         # BaseUnit scale might be different depending on exponent
         true_scale = scale
         if parent_exponent != 1.0:
-            true_scale = math.pow(scale, 1.0/parent_exponent)
+            true_scale = math.pow(scale, 1.0 / parent_exponent)
         new_base_unit.define_conversion_factor_to(parent_base_unit, true_scale)
         new_unit = Unit({new_base_unit: 1.0})
         return new_unit
-        
+
     def iter_base_dimensions(self):
         """
         Yields (BaseDimension, exponent) tuples comprising this unit.
         """
         # There might be two units with the same dimension? No.
         for dimension in sorted(self._all_base_units.keys()):
-            exponent = 0
-            for base_unit in sorted(self._all_base_units[dimension].keys()):
-                exponent += self._all_base_units[dimension][base_unit]
+            exponent = sum(self._all_base_units[dimension].values())
             if exponent != 0:
                 yield (dimension, exponent)
 
@@ -138,7 +133,7 @@ class Unit(object):
         """
         Yields (BaseUnit, exponent) tuples comprising this unit, including those BaseUnits
         found within ScaledUnits.
-        
+
         There might be multiple BaseUnits with the same dimension.
         """
         for dimension in sorted(self._all_base_units.keys()):
@@ -154,16 +149,13 @@ class Unit(object):
             for unit in sorted(self._top_base_units[dimension].keys()):
                 exponent = self._top_base_units[dimension][unit]
                 yield (unit, exponent)
-            
+
     def iter_scaled_units(self):
-        for unit, exponent in self._scaled_units:
-            yield (unit, exponent)
+        yield from self._scaled_units
 
     def iter_base_or_scaled_units(self):
-        for item in self.iter_top_base_units():
-            yield item
-        for item in self.iter_scaled_units():
-            yield item
+        yield from self.iter_top_base_units()
+        yield from self.iter_scaled_units()
 
     def get_conversion_factor_to_base_units(self):
         """
@@ -175,28 +167,37 @@ class Unit(object):
         factor = 1.0
         for scaled_unit, exponent in self._scaled_units:
             # print scaled_unit.factor
-            factor *= scaled_unit.factor ** exponent
+            factor *= scaled_unit.factor**exponent
         return factor
-        
+
     def __eq__(self, other):
         if not is_unit(other):
             return False
         return self.get_name() == other.get_name()
 
     def __ne__(self, other):
-        return not self.__eq__(other)
+        return not self == other
 
     def __lt__(self, other):
         """Compare two Units.
-        
+
         Raises a TypeError if the units have different dimensions.
-        
+
         Returns True if self < other, False otherwise.
         """
         if not self.is_compatible(other):
             raise TypeError('Unit "%s" is not compatible with Unit "%s".', (self, other))
         return self.conversion_factor_to(other) < 1.0
 
+    def __le__(self, other):
+        return self.__lt__(other) or self.__eq__(other)
+
+    def __gt__(self, other):
+        return other.__lt__(self)
+
+    def __ge__(self, other):
+        return other.__lt__(self) or other.__eq__(self)
+
     def __hash__(self):
         """
         Compute a hash code for this object.
@@ -210,12 +211,12 @@ class Unit(object):
 
     # def __mul__(self, other):
     # See unit_operators.py for Unit.__mul__ operator
-    
+
     def __truediv__(self, other):
         """Divide a Unit by another object.
-        
+
         Returns a composite Unit if other is another Unit.
-        
+
         Returns a Quantity otherwise.  UNLESS other is a Quantity AND
         the resulting unit type is dimensionless, in which case the underlying
         value type of the Quantity is returned.
@@ -231,7 +232,7 @@ class Unit(object):
 
     def __pow__(self, exponent):
         """Raise a Unit to a power.
-        
+
         Returns a new Unit with different exponents on the BaseUnits.
         """
         if self in Unit._pow_cache:
@@ -239,7 +240,7 @@ class Unit(object):
                 return Unit._pow_cache[self][exponent]
         else:
             Unit._pow_cache[self] = {}
-        result = {} # dictionary of unit: exponent
+        result = {}  # dictionary of unit: exponent
         for unit, exponent2 in self.iter_base_or_scaled_units():
             result[unit] = exponent2 * exponent
         new_unit = Unit(result)
@@ -249,7 +250,7 @@ class Unit(object):
     def sqrt(self):
         """
         Returns square root of a unit.
-        
+
         Raises ArithmeticError if component exponents are not even.
         This behavior can be changed if you present a reasonable real life case to me.
         """
@@ -259,11 +260,11 @@ class Unit(object):
         # But if ScaledUnits and BaseUnits have even exponents, we should use them.
         nice_and_even = True
         for u, exponent in self.iter_base_or_scaled_units():
-            if exponent%2 != 0:
+            if exponent % 2 != 0:
                 # This isn't going to work, we need to bust apart the ScaledUnits
                 nice_and_even = False
                 break
-            new_units[u] = exponent/2
+            new_units[u] = exponent / 2
         if not nice_and_even:
             # Create a new unit formed from inner BaseUnits
             new_units = {}
@@ -280,15 +281,15 @@ class Unit(object):
                     new_units[bu] += exponent
             # If exponents are not even by now, they never will be even
             for u, exponent in new_units.items():
-                if exponent%2 != 0:
-                    raise ArithmeticError('Exponents in Unit.sqrt() must be even.')
-                new_units[u] = exponent/2
+                if exponent % 2 != 0:
+                    raise ArithmeticError("Exponents in Unit.sqrt() must be even.")
+                new_units[u] = exponent / 2
         return Unit(new_units)
 
     def __str__(self):
         """Returns the human-readable name of this unit"""
         return self.get_name()
-        
+
     def __repr__(self):
         """
         Returns a unit name (string) for this Unit, composed of its various
@@ -297,7 +298,7 @@ class Unit(object):
         units = {}
         for unit, power in self.iter_base_or_scaled_units():
             units[unit] = power
-        return 'Unit(%s)' % repr(units)
+        return "Unit(%s)" % repr(units)
 
     # Performance
     _is_compatible_cache = {}
@@ -324,12 +325,12 @@ class Unit(object):
         if len(self_dims) != len(other_dims):
             result = False
         else:
-            result = (self_dims == other_dims)
-        if not self in Unit._is_compatible_cache:
+            result = self_dims == other_dims
+        if self not in Unit._is_compatible_cache:
             Unit._is_compatible_cache[self] = {}
         Unit._is_compatible_cache[self][other] = result
         return result
-    
+
     _is_dimensionless_cache = {}
 
     def is_dimensionless(self):
@@ -344,7 +345,7 @@ class Unit(object):
                 return False
         Unit._is_dimensionless_cache[self] = True
         return True
-        
+
     # Performance
     _conversion_factor_cache = {}
 
@@ -352,7 +353,7 @@ class Unit(object):
         """
         Returns conversion factor for computing all of the common dimensions
         between self and other from self base units to other base units.
-        
+
         The two units need not share all of the same dimensions.  In case they
         do not, the conversion factor applies only to the BaseUnits of self
         that correspond to different BaseUnits in other.
@@ -360,7 +361,7 @@ class Unit(object):
         This method requires strict compatibility between the two units.
         """
         factor = 1.0
-        if (self is other): 
+        if self is other:
             return factor
         if self in Unit._conversion_factor_cache:
             if other in Unit._conversion_factor_cache[self]:
@@ -368,24 +369,39 @@ class Unit(object):
         assert self.is_compatible(other)
         factor *= self.get_conversion_factor_to_base_units()
         factor /= other.get_conversion_factor_to_base_units()
-        # Organize both units' base units by dimension
 
-        canonical_units = {} # dimension: BaseUnit
+        # Organize both units' base units by dimension.  Since so many conversion factors
+        # are powers of ten, we accumulate them separately as an integer power to reduce
+        # numerical error.
+
+        canonical_units = {}  # dimension: BaseUnit
+        powers_of_ten = 0
         for unit, power in self.iter_all_base_units():
             d = unit.dimension
             if d in canonical_units:
                 if unit != canonical_units[d]:
-                    factor *= unit.conversion_factor_to(canonical_units[d])**power
+                    conversion = unit.conversion_factor_to(canonical_units[d])
+                    log_conversion = math.log10(conversion)
+                    if log_conversion == int(log_conversion):
+                        powers_of_ten += power * int(log_conversion)
+                    else:
+                        factor *= conversion**power
             else:
                 canonical_units[d] = unit
         for unit, power in other.iter_all_base_units():
             d = unit.dimension
             if d in canonical_units:
                 if unit != canonical_units[d]:
-                    factor /= unit.conversion_factor_to(canonical_units[d])**power
+                    conversion = unit.conversion_factor_to(canonical_units[d])
+                    log_conversion = math.log10(conversion)
+                    if log_conversion == int(log_conversion):
+                        powers_of_ten -= power * int(log_conversion)
+                    else:
+                        factor /= conversion**power
             else:
                 canonical_units[d] = unit
-        if not self in Unit._conversion_factor_cache:
+        factor *= 10**powers_of_ten
+        if self not in Unit._conversion_factor_cache:
             Unit._conversion_factor_cache[self] = {}
         Unit._conversion_factor_cache[self][other] = factor
         return factor
@@ -393,11 +409,12 @@ class Unit(object):
     def in_unit_system(self, system):
         """
         Returns a new Unit with the same dimensions as this one, expressed in a particular unit system.
-        
+
         Strips off any ScaledUnits in the Unit, leaving only BaseUnits.
-        
+
         Parameters
-         - system: a dictionary of (BaseDimension, BaseUnit) pairs
+        ----------
+        system : a dictionary of (BaseDimension, BaseUnit) pairs
         """
         return system.express_unit(self)
 
@@ -410,10 +427,11 @@ class Unit(object):
         # emit positive exponents first
         pos = ""
         pos_count = 0
-        for unit, power in self.iter_base_or_scaled_units():            
+        for unit, power in self.iter_base_or_scaled_units():
             if power > 0:
                 pos_count += 1
-                if pos_count > 1: pos += " "
+                if pos_count > 1:
+                    pos += " "
                 pos += unit.symbol
                 if power != 1.0:
                     pos += "**%g" % power
@@ -421,15 +439,16 @@ class Unit(object):
         neg = ""
         neg_count = 0
         simple_denominator = True
-        for unit, power in self.iter_base_or_scaled_units():            
+        for unit, power in self.iter_base_or_scaled_units():
             if power < 0:
                 neg_count += 1
-                if neg_count > 1: neg += " "
+                if neg_count > 1:
+                    neg += " "
                 neg += unit.symbol
                 if power != -1.0:
                     neg += "**%g" % -power
                     simple_denominator = False
-        # Format of denominator depends on number of terms 
+        # Format of denominator depends on number of terms
         if 0 == neg_count:
             neg_string = ""
         elif 1 == neg_count and simple_denominator:
@@ -443,7 +462,7 @@ class Unit(object):
         if 0 == pos_count == neg_count:
             symbol = "dimensionless"
         else:
-            symbol = "%s%s" % (pos_string, neg_string)
+            symbol = f"{pos_string}{neg_string}"
         return symbol
 
     def get_name(self):
@@ -458,10 +477,11 @@ class Unit(object):
         # emit positive exponents first
         pos = ""
         pos_count = 0
-        for unit, power in self.iter_base_or_scaled_units():            
+        for unit, power in self.iter_base_or_scaled_units():
             if power > 0:
                 pos_count += 1
-                if pos_count > 1: pos += "*"
+                if pos_count > 1:
+                    pos += "*"
                 pos += unit.name
                 if power != 1.0:
                     pos += "**%g" % power
@@ -469,15 +489,16 @@ class Unit(object):
         neg = ""
         neg_count = 0
         simple_denominator = True
-        for unit, power in self.iter_base_or_scaled_units():            
+        for unit, power in self.iter_base_or_scaled_units():
             if power < 0:
                 neg_count += 1
-                if neg_count > 1: neg += "*"
+                if neg_count > 1:
+                    neg += "*"
                 neg += unit.name
                 if power != -1.0:
                     neg += "**%g" % -power
                     simple_denominator = False
-        # Format of denominator depends on number of terms 
+        # Format of denominator depends on number of terms
         if 0 == neg_count:
             neg_string = ""
         elif 1 == neg_count and simple_denominator:
@@ -491,18 +512,21 @@ class Unit(object):
         if 0 == pos_count == neg_count:
             name = "dimensionless"
         else:
-            name = "%s%s" % (pos_string, neg_string)
+            name = f"{pos_string}{neg_string}"
         self._name = name
         return name
 
 
-class ScaledUnit(object):
+class ScaledUnit:
     """
     ScaledUnit is like a BaseUnit, but it is based on another Unit.
-    
+
     ScaledUnit and BaseUnit are both used in the internals of Unit.  They
     should only be used during the construction of Units.
     """
+
+    __array_priority__ = 100
+
     def __init__(self, factor, master, name, symbol):
         self.factor = factor
         # Convert to one base_unit per dimension
@@ -526,8 +550,7 @@ class ScaledUnit(object):
             yield self.base_units[dim]
 
     def iter_base_units(self):
-        for base_unit, exponent in self:
-            yield(base_unit, exponent)
+        yield from self
 
     def iter_base_dimensions(self):
         """
@@ -541,13 +564,13 @@ class ScaledUnit(object):
         """
         Returns a sorted tuple of (BaseDimension, exponent) pairs, that can be used as a dictionary key.
         """
-        l = list(self.iter_base_dimensions())
-        l.sort()
-        return tuple(l)
-        
+        _list = list(self.iter_base_dimensions())
+        _list.sort()
+        return tuple(_list)
+
     def get_conversion_factor_to_base_units(self):
         return self.factor
-        
+
     def conversion_factor_to(self, other):
         # Create fake unit based on base units
         if self is other:
@@ -562,28 +585,43 @@ class ScaledUnit(object):
         return self.factor * Unit(u).conversion_factor_to(other_u)
 
     def __lt__(self, other):
-        """Compare two ScaledUnits.
-        """
+        """Compare two ScaledUnits."""
         return hash(self) < hash(other)
-        
+
     def __str__(self):
-        """Returns a string with the name of this ScaledUnit
-        """
+        """Returns a string with the name of this ScaledUnit"""
         return self.name
 
     def __repr__(self):
-        """
-        """
+        """ """
         base_units = ""
         for base_unit, power in self.iter_base_units():
             if len(base_units) > 0:
                 base_units += ", "
             base_units += "%s: %d" % (base_unit, power)
-        return "ScaledUnit(factor=" + repr(self.factor) + \
-                ", master="+str(self.master)+", name=" + repr(self.name)\
-                + ", symbol=" + repr(self.symbol) + ")"
+        return (
+            "ScaledUnit(factor="
+            + repr(self.factor)
+            + ", master="
+            + str(self.master)
+            + ", name="
+            + repr(self.name)
+            + ", symbol="
+            + repr(self.symbol)
+            + ")"
+        )
+
+
+class UnitSystem:
+    """
+    A complete system of units defining the *base* unit in each dimension
+
+    Parameters
+    ----------
+    units : list
+        List of base units from which to construct the unit system
+    """
 
-class UnitSystem(object):
     def __init__(self, units):
         self.units = units
         self._unit_conversion_cache = {}
@@ -612,19 +650,17 @@ class UnitSystem(object):
         try:
             self.from_base_units = ~to_base_units
         except ArithmeticError as e:
-        # for compatibility between python 2.5 and python 3.0,
-        # try replacing line above with the following two lines:
-        # except ArithmeticError:
-        #     e=sys.exc_info[1]
+            # for compatibility between python 2.5 and python 3.0,
+            # try replacing line above with the following two lines:
+            # except ArithmeticError:
+            #     e=sys.exc_info[1]
             raise ArithmeticError("UnitSystem is not a valid basis set.  " + str(e))
-    
+
     def __iter__(self):
-        for unit in self.units:
-            yield unit
+        yield from self.units
 
     def __str__(self):
-        """
-        """
+        """ """
         result = "UnitSystem(["
         sep = ""
         for unit in self:
@@ -635,8 +671,7 @@ class UnitSystem(object):
         return result
 
     def express_unit(self, old_unit):
-        """
-        """
+        """ """
         if old_unit in self._unit_conversion_cache:
             return self._unit_conversion_cache[old_unit]
         # First express unit in terms of base dimensions found in this unit system
@@ -650,7 +685,7 @@ class UnitSystem(object):
             else:
                 other_dims[dim] = exponent
         # Multiply by self.from_base_units to convert to unit system units
-        u = MyMatrix([base_dims,]) * self.from_base_units
+        u = MyMatrix([base_dims]) * self.from_base_units
         new_unit = dimensionless
         for i in range(m):
             exponent = u[0][i]
@@ -662,32 +697,34 @@ class UnitSystem(object):
             for base_unit, useless_exponent in old_unit.iter_all_base_units():
                 dim = base_unit.dimension
                 if dim not in other_dims:
-                    continue # this dimension is in the unit system
+                    continue  # this dimension is in the unit system
                 if dim in found_dims:
-                    continue # already got a BaseUnit for this dimension
+                    continue  # already got a BaseUnit for this dimension
                 found_dims[dim] = base_unit
                 exponent = other_dims[dim]
                 new_unit *= Unit({base_unit: exponent})
         self._unit_conversion_cache[old_unit] = new_unit
         return new_unit
 
+
 def is_unit(x):
     """
     Returns True if x is a Unit, False otherwise.
-    
+
     Examples
-    
+    --------
     >>> is_unit(16)
     False
     """
     return isinstance(x, Unit)
 
-    
+
 dimensionless = Unit({})
 
-
 # run module directly for testing
-if __name__=='__main__':
+if __name__ == "__main__":
     # Test the examples in the docstrings
-    import doctest, sys
+    import doctest
+    import sys
+
     doctest.testmod(sys.modules[__name__])
