@@ -31,13 +31,13 @@ DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR
 OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE
 USE OR OTHER DEALINGS IN THE SOFTWARE.
 """
-from __future__ import division, print_function, absolute_import
 
 __author__ = "Christopher M. Bruns"
 __version__ = "0.5"
 
 
 import math
+
 from .quantity import is_quantity
 from .unit_definitions import *
 
@@ -45,6 +45,7 @@ from .unit_definitions import *
 ### TRIGONOMETRY ###
 ####################
 
+
 def sin(angle):
     """
     Examples
@@ -53,16 +54,18 @@ def sin(angle):
     1.0
     """
     if is_quantity(angle):
-        return math.sin(angle/radians)
+        return math.sin(angle / radians)
     else:
         return math.sin(angle)
 
+
 def sinh(angle):
     if is_quantity(angle):
-        return math.sinh(angle/radians)
+        return math.sinh(angle / radians)
     else:
         return math.sinh(angle)
 
+
 def cos(angle):
     """
     Examples
@@ -71,28 +74,32 @@ def cos(angle):
     -1.0
     """
     if is_quantity(angle):
-        return math.cos(angle/radians)
+        return math.cos(angle / radians)
     else:
         return math.cos(angle)
 
+
 def cosh(angle):
     if is_quantity(angle):
-        return math.cosh(angle/radians)
+        return math.cosh(angle / radians)
     else:
         return math.cosh(angle)
 
+
 def tan(angle):
     if is_quantity(angle):
-        return math.tan(angle/radians)
+        return math.tan(angle / radians)
     else:
         return math.tan(angle)
 
+
 def tanh(angle):
     if is_quantity(angle):
-        return math.tanh(angle/radians)
+        return math.tanh(angle / radians)
     else:
         return math.tanh(angle)
 
+
 def acos(x):
     """
     >>> acos(1.0)
@@ -102,28 +109,36 @@ def acos(x):
     """
     return math.acos(x) * radians
 
+
 def acosh(x):
     return math.acosh(x) * radians
 
+
 def asin(x):
     return math.asin(x) * radians
 
+
 def asinh(x):
     return math.asinh(x) * radians
 
+
 def atan(x):
     return math.atan(x) * radians
 
+
 def atanh(x):
     return math.atanh(x) * radians
 
+
 def atan2(x, y):
     return math.atan2(x, y) * radians
 
+
 ###################
 ### SQUARE ROOT ###
 ###################
 
+
 def sqrt(val):
     """
     >>> sqrt(9.0)
@@ -142,10 +157,12 @@ def sqrt(val):
     except AttributeError:
         return math.sqrt(val)
 
+
 ###########
 ### SUM ###
 ###########
 
+
 def sum(val):
     """
     >>> sum((1.0, 2.0))
@@ -166,20 +183,23 @@ def sum(val):
         result += val[i]
     return result
 
+
 ###################
 ### VECTOR MATH ###
 ###################
 
+
 def dot(x, y):
     """
     >>> dot((2, 3)*meter, (4, 5)*meter)
     Quantity(value=23, unit=meter**2)
     """
-    sum = x[0]*y[0]
+    sum = x[0] * y[0]
     for i in range(1, len(x)):
-        sum += x[i]*y[i]
+        sum += x[i] * y[i]
     return sum
 
+
 def norm(x):
     """
     >>> norm((3, 4)*meter)
@@ -187,8 +207,11 @@ def norm(x):
     """
     return sqrt(dot(x, x))
 
+
 # run module directly for testing
-if __name__=='__main__':
+if __name__ == "__main__":
     # Test the examples in the docstrings
-    import doctest, sys
+    import doctest
+    import sys
+
     doctest.testmod(sys.modules[__name__])
