@@ -22,8 +22,8 @@
 
 import os
 import pickle
+import shutil
 import tarfile
-from distutils.spawn import find_executable
 
 import numpy as np
 import pytest
@@ -56,7 +56,7 @@ def test_load_mol2(get_fn):
     eq(bonds, ref_bonds)
 
 
-@pytest.mark.skipif(find_executable("obabel") is None, reason="Requires obabel")
+@pytest.mark.skipif(shutil.which("obabel") is None, reason="Requires obabel")
 @pytest.mark.skipif(os.environ.get("TRAVIS", None) == "true", reason="Skip on Travis.")
 def test_load_freesolv_gaffmol2_vs_sybylmol2_vs_obabelpdb(get_fn, tmpdir):
     tar_filename = "freesolve_v0.3.tar.bz2"
